@@ -1,9 +1,9 @@
 .onLoad <- function(lib, pkg){
-    require("methods", character = TRUE, quietly = TRUE)
-## are the following calls to require necessary?
-    require("distr", character = TRUE, quietly = TRUE)
-    require("distrEx", character = TRUE, quietly = TRUE)
-    require("RandVar", character = TRUE, quietly = TRUE)
+#    require("methods", character = TRUE, quietly = TRUE)
+### are the following calls to require necessary?
+#    require("distr", character = TRUE, quietly = TRUE)
+#    require("distrEx", character = TRUE, quietly = TRUE)
+#    require("RandVar", character = TRUE, quietly = TRUE)
 }
 
 .onAttach <- function(library, pkg){
@@ -112,6 +112,19 @@ setClass("ParamFamParameter",
                 return(TRUE)}
             })
 
+setClass("ParamWithScaleFamParameter",
+            contains = "ParamFamParameter")
+
+setClass("ParamWithShapeFamParameter",
+            representation(withPosRestr = "logical"),
+            prototype(withPosRestr = TRUE),
+            contains = "ParamFamParameter")
+
+setClass("ParamWithScaleAndShapeFamParameter",
+            contains = c("ParamWithScaleFamParameter",
+                         "ParamWithShapeFamParameter")
+         )
+
 ### from Matthias' thesis / ROptEst
 ## family of probability measures
 setClass("ProbFamily", representation(name = "character",
@@ -143,6 +156,7 @@ setClass("ParamFamily",
                       param = new("ParamFamParameter", main = 0, trafo = matrix(1))),
             contains = "ProbFamily")
 
+
 ### from Matthias' thesis / ROptEst
 ## L2-differentiable parametric family of probability measures
 setClass("L2ParamFamily",
@@ -212,12 +226,23 @@ setClass("L2GroupParamFamily",
                       Logderiv = function(x)x),
             contains = "L2ParamFamily")
 
+
+
 ## virtual in-between class for common parts in modifyModel - method
 setClass("L2LocationScaleUnion",
             representation(locscalename = "character"),
          contains = c("L2GroupParamFamily","VIRTUAL")
         )
 
+## virtual in-between class for common parts in modifyModel - method
+setClass("L2ScaleShapeUnion", representation(scaleshapename ="character"),
+         contains = c("L2GroupParamFamily","VIRTUAL")
+        )
+
+## virtual in-between class for common parts log/original scale methods
+setClassUnion("L2ScaleUnion",
+               c("L2LocationScaleUnion","L2ScaleShapeUnion")
+               )
 
 ## L2-differentiable (univariate) location family
 setClass("L2LocationFamily",
@@ -237,6 +262,7 @@ setClass("L2LocationScaleFamily",
                                   fam.call = call("new", "L2LocationScaleFamily")),
             contains = "L2LocationScaleUnion")
 
+
 ################################################################################
 ## Norm Classes
 ################################################################################
